# Generated by roxygen2: do not edit by hand

export(chars_structure)
export(chars_structure_general)
export(convert_all)
export(convert_r)
export(detect_chars_structure)
export(detect_chars_structure_datasets)
export(dupl_show)
export(dupl_sources)
export(folder_structure_replicate)
export(inspect)
export(inspect_vars)
export(inspect_write)
export(ljoin_checks)
export(mask_convert_r)
export(mask_rename_r)
export(path_move)
export(rename_r)
export(replace_multiple)
export(table_prop)
export(vars_compclasses)
export(vars_compclasses_allsame)
export(vars_compclasses_not_allsame)
export(vars_detect)
export(vars_detect_everywhere)
export(vars_detect_not_everywhere)
importFrom(glue,glue)
importFrom(magrittr,"%>%")
importFrom(stats,nobs)
