% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inspect.R
\name{inspect}
\alias{inspect}
\title{Inspect a data frame}
\usage{
inspect(data_frame, nrow = FALSE)
}
\arguments{
\item{data_frame}{A data frame to inspect.}

\item{nrow}{Logical. If \code{TRUE}, the number of observations is printed
as a message in addition to the returned table.}
}
\value{
A tibble with one row per variable and columns: \code{variables},
\code{class}, \code{nb_distinct}, \code{prop_distinct}, \code{nb_na},
\code{prop_na}, \code{nb_void}, \code{prop_void}, \code{nchars}, \code{modalities}.
}
\description{
Compute a summary of each variable in a data frame: class, distinct values,
missing values, void strings, character lengths, and sample modalities.
}
\examples{
inspect(CO2)
}
