% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vars_compclasses.R
\name{vars_compclasses}
\alias{vars_compclasses}
\title{Collection-level variables types comparison}
\usage{
vars_compclasses(data_frames)
}
\arguments{
\item{data_frames}{A named list of data frames to compare.}
}
\value{
A data frame with a \code{vars_union} column and one column per dataset
showing the class of each variable (\code{"-"} if absent from that dataset).
}
\description{
Compare the class of each variable across a collection of datasets.
}
\examples{
data_list <- list(cars = cars, mtcars = mtcars)
vars_compclasses(data_list)
}
