% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vars_compclasses_not_allsame.R
\name{vars_compclasses_not_allsame}
\alias{vars_compclasses_not_allsame}
\title{Variable class comparison - inconsistent types across datasets}
\usage{
vars_compclasses_not_allsame(vars_compclasses_table)
}
\arguments{
\item{vars_compclasses_table}{Output of the \code{vars_compclasses()} function.}
}
\value{
A subset of \code{vars_compclasses_table} containing only variables
with different classes across datasets where they appear.
}
\description{
Variable class comparison - inconsistent types across datasets
}
\examples{
data_list <- list(cars = cars, mtcars = mtcars)
vcompclasses <- vars_compclasses(data_list)
vars_compclasses_not_allsame(vcompclasses)
}
